@@ -12,7 +12,10 @@ def parse():
     parser.add_argument('judge_output', help='judge output file')
 
     parser.add_argument('-v', '--verbose',
-            help='Print result to stdout', action='store_true')
+            help='print result to stdout', action='store_true')
+
+    parser.add_argument('-c', '--checker', type=str,
+            help='path to optional custom checker with same input form')
 
     group = parser.add_mutually_exclusive_group()
     group.add_argument('-t', '--tok',
